@@ -1,12 +1,11 @@
 import json
 from pathlib import Path
-from typing import Dict
 
 from erdb.typing.game_version import GameVersion, GameVersionRange
 from erdb.loaders import PKG_DATA_PATH
 
 
-def _overlay_properties(ret: Dict, source: Dict):
+def _overlay_properties(ret: dict, source: dict):
     """
     Append to lists and sets, override scalars and dictionaries
     """
@@ -14,11 +13,11 @@ def _overlay_properties(ret: Dict, source: Dict):
         if isinstance(value, list):
             ret[key] = ret.get(key, list()) + value
         elif isinstance(value, set):
-            ret[key] = ret.get(key, set()) + value
+            ret[key] = ret.get(key, set()) + value # type: ignore
         else:
             ret[key] = value
 
-def _parse_user_file(path: Path, version: GameVersion) -> Dict:
+def _parse_user_file(path: Path, version: GameVersion) -> dict:
     assert path.is_file
     assert path.suffix == ".json"
 
@@ -33,7 +32,7 @@ def _parse_user_file(path: Path, version: GameVersion) -> Dict:
 
     return ret
 
-def load(element: str, version: GameVersion) -> Dict[str, Dict]:
+def load(element: str, version: GameVersion) -> dict[str, dict]:
     path = PKG_DATA_PATH / "contrib" / element
     files = path.iterdir() if path.is_dir() else []
     return {f.stem: _parse_user_file(f, version) for f in files}
\ No newline at end of file
