@@ -1,9 +1,9 @@
 import json
 from pathlib import Path
-from typing import Dict, List, Sequence
+from typing import Sequence
 
 from erdb.main.args import parse_args
-from erdb.generators import Table
+from erdb.table import Table
 from erdb.loaders import GAME_VERSIONS
 from erdb.app_api.main import serve as serve_app_api
 from erdb.utils.attack_power import Attributes, CalculatorData, ArmamentCalculator
@@ -15,7 +15,7 @@ from erdb.typing.game_version import GameVersion, GameVersionRange
 
 
 class App:
-    args: Dict
+    args: dict
 
     def __init__(self, argv: Sequence[str]) -> None:
         self.args = parse_args(argv, handlers={
@@ -34,7 +34,7 @@ class App:
         return handler(**self.args)
 
     @staticmethod
-    def generate(tables: List[Table], gamedata: GameVersionRange, minimize: bool, out: Path | None) -> int:
+    def generate(tables: list[Table], gamedata: GameVersionRange, minimize: bool, out: Path | None) -> int:
         if out is None:
             out = Path.cwd()
         else:
@@ -44,10 +44,10 @@ class App:
             destination = out / str(version)
             destination.mkdir(parents=True, exist_ok=True)
 
-            for gen in (tb.make_generator(version) for tb in tables):
-                print(f"\n>>> Generating \"{gen.element_name()}\" from version {version}", flush=True)
+            for tb, gen in ((tb, tb.make_generator(version)) for tb in tables):
+                print(f"\n>>> Generating \"{tb}\" from version {version}", flush=True)
 
-                output_file = destination / gen.output_file()
+                output_file = destination / f"{tb}.json"
                 print(f"Output file: {output_file}", flush=True)
 
                 if output_file.exists():
@@ -66,7 +66,7 @@ class App:
     def find_values(param: str, field: str, limit: int, gamedata: GameVersionRange) -> int:
         for game_version in gamedata.iterate(GAME_VERSIONS):
             print(f"\n>>> Finding values for version {game_version}")
-            find_valid_values(param, game_version, field, limit)
+            find_valid_values(param, str(game_version), field, limit)
 
         return 0
 
@@ -137,7 +137,7 @@ class App:
         return 0
 
     @staticmethod
-    def source_icons(types: List[Table], size: int, game_dir: Path, ignore_checksum: bool, keep_cache: bool, out: Path | None) -> int:
+    def source_icons(types: list[Table], size: int, game_dir: Path, ignore_checksum: bool, keep_cache: bool, out: Path | None) -> int:
         game_dir = game_dir.resolve()
 
         if out is None:
